baseObjects.Workflow

|  | ## Cheshire3 Object Model: Class Workflow

Module baseObjects :: Class Workflow

## Class Workflow
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           Workflow

Known Subclasses:
  workflow.SimpleWorkflow

A workflow is similar to the process chain concept of an index, but behaves at a more global level. It will allow the configuration of a workflow using Cheshire3 objects and simple code to be defined and executed for input objects. For example, one might define a common workflow pattern of PreParsers, a Parser and then indexing routines in the XML configuration, and then run each document in a documentFactory through it. This allows users who are not familiar with Python, but who are familiar with XML and the Cheshire3 design to implement tasks as required by changing only configuration files. It thus also allows a user to configure personal workflows in a Cheshire3 system which they don't have permission to modify.
Instance Methods

process(self, session, *args, **kw) Executes the code as constructed from the XML configuration on the given object.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

code |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### process(self, session, *args, **kw) | source code
Executes the code as constructed from the XML configuration on the given object. The return value is the last object to be produced by the execution. This function is automatically written and compiled when the object is instantiated.

Class Variable Details

    ### code Value:
        ''